import { ChangeDetectorRef, EventEmitter, IterableDiffers, QueryList, DoCheck } from '@angular/core';
import { IgxChipComponent } from './chip.component';
export declare class IgxChipsAreaComponent implements DoCheck {
    cdr: ChangeDetectorRef;
    private _iterableDiffers;
    /**
     * @hidden
     */
    cssClass: string;
    /**
     * An @Input property that sets the width of the `IgxChipsAreaComponent`.
     * ```html
     * <igx-chips-area #chipsArea [width]="'300'" [height]="'10'" (onReorder)="chipsOrderChanged($event)"></igx-chips-area>
     * ```
     */
    width: number;
    /**
     * An @Input property that sets the height of the `IgxChipsAreaComponent`.
     * ```html
     * <igx-chips-area #chipsArea [width]="'300'" [height]="'10'" (onReorder)="chipsOrderChanged($event)"></igx-chips-area>
     * ```
     */
    height: number;
    /**
     * Emits an event when an `IgxChipComponent` in the `IgxChipsAreaComponent` are reordered.
     * ```html
     * <igx-chips-area #chipsArea [width]="'300'" [height]="'10'" (onReorder)="changedOrder()"></igx-chips-area>
     * ```
     * ```typescript
     * public changedOrder(){
     *      alert("The order has been changed!");
     * }
     * ```
     */
    onReorder: EventEmitter<any>;
    /**
     * Emits an event when an `IgxChipComponent` in the `IgxChipsAreaComponent` is selected.
     * ```html
     * <igx-chips-area #chipsArea [width]="'300'" [height]="'10'" (onSelection)="selection()"></igx-chips-area>
     * ```
     * ```typescript
     * public selection(){
     *      alert("A chip has been selected!");
     * }
     */
    onSelection: EventEmitter<any>;
    /**
     * Emits an event when an `IgxChipComponent` in the `IgxChipsAreaComponent` is moved.
     * ```html
     * <igx-chips-area #chipsArea [width]="'300'" [height]="'10'" (onMoveStart)="moveStart()"></igx-chips-area>
     * ```
     * ```typescript
     * moveStart(){
     *      alert("A chip has started moving!");
     * }
     * ```
     */
    onMoveStart: EventEmitter<any>;
    /**
     * Emits an event after an `IgxChipComponent` in the `IgxChipsAreaComponent` is moved.
     * ```html
     * <igx-chips-area #chipsArea [width]="'300'" [height]="'10'" (onMoveEnd)="moveEnd()"></igx-chips-area>
     * ```
     * ```typescript
     * moveEnd(){
     *      alert("A chip has been moved!");
     * }
     * ```
     */
    onMoveEnd: EventEmitter<any>;
    /**
     * Holds the `IgxChipComponent` in the `IgxChipsAreaComponent`.
     * ```typescript
     * ngAfterViewInit(){
     *    let chips = this.chipsArea.chipsList;
     * }
     * ```
     */
    chipsList: QueryList<IgxChipComponent>;
    private modifiedChipsArray;
    private _differ;
    private selectedChips;
    constructor(cdr: ChangeDetectorRef, _iterableDiffers: IterableDiffers);
    /**
     * @hidden
     */
    ngDoCheck(): void;
    /**
     * @hidden
     */
    protected onChipKeyDown(event: any): void;
    /**
     * @hidden
     */
    protected onChipMoveStart(): void;
    /**
     * @hidden
     */
    protected onChipMoveEnd(): void;
    /**
     * @hidden
     */
    protected onChipDragEnter(event: any): void;
    /**
     * @hidden
     */
    protected positionChipAtIndex(chipIndex: any, targetIndex: any, shiftRestLeft: any): boolean;
    /**
     * @hidden
     */
    protected onChipSelectionChange(event: any): void;
}
