export declare class IgxSelectionAPIService {
    protected selection: Map<string, Set<any>>;
    get_selection(componentID: string): Set<any>;
    set_selection(componentID: string, currSelection: Set<any>): void;
    get_selection_length(componentID: string): number;
    /**
     * Add item to component selection using item's ID.
     * @param componentID ID of the component, which we add new item to.
     * @param itemID ID of the item to add to component selection.
     * @param sel Used internally only by the selection (select_items method) to accumulate selection for multiple items.
     *
     * @returns selection after the new item is added
     */
    select_item(componentID: string, itemID: any, sel?: Set<any>): Set<any>;
    /**
     * Add items to component selection using their IDs.
     * @param componentID ID of the component, which we add new items to.
     * @param itemIDs Array of IDs of the items to add to component selection.
     *
     * @returns selection after the new item is added
     */
    select_items(componentID: string, itemIDs: any[], clearSelection?: boolean): Set<any>;
    /**
     * Remove item from component selection using item's ID.
     * @param componentID ID of the component, which we remove items from.
     * @param itemID ID of the item to remove from component selection.
     * @param sel Used internally only by the selection (deselect_items method) to accumulate deselected items.
     *
     * @returns selection after the item is removed
     */
    deselect_item(componentID: string, itemID: any, sel?: Set<any>): Set<any>;
    /**
     * Remove items from component selection using their IDs.
     * @param componentID ID of the component, which we remove items from.
     * @param itemID ID of the items to remove from component selection.
     *
     * @returns selection after the item is removed
     */
    deselect_items(componentID: string, itemIDs: any[]): Set<any>;
    is_item_selected(componentID: string, itemID: any): boolean;
    get_selection_first(componentID: string): any;
    get_all_ids(data: any, primaryKey?: any): any;
    are_all_selected(componentID: string, data: any): boolean;
    are_none_selected(componentID: string): boolean;
}
